summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/webplugin_delegate_proxy.h
diff options
context:
space:
mode:
authorstuartmorgan@chromium.org <stuartmorgan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-21 21:15:13 +0000
committerstuartmorgan@chromium.org <stuartmorgan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-01-21 21:15:13 +0000
commitb7f75868cb53eb45d3e15263a663327e381d40db (patch)
treebc2faeff6b2f1137e79be528168a26decc646231 /chrome/renderer/webplugin_delegate_proxy.h
parentdb5523bcb7e0419955172709c241a188ab94e8e0 (diff)
downloadchromium_src-b7f75868cb53eb45d3e15263a663327e381d40db.zip
chromium_src-b7f75868cb53eb45d3e15263a663327e381d40db.tar.gz
chromium_src-b7f75868cb53eb45d3e15263a663327e381d40db.tar.bz2
Update Mac plugin IME handling to match updated spec
This changes IME handling per the recent NPAPI spec clarification, and adds the new bool to indicate conformance to the new model. Also: - Fixes an existing bug where the initial key down would be sent to the wrong IME system (since it happens before plugin IME starts) by having the render widget track whether a plugin is focused. - Changes ComplexTextInputPanel to match recent upstream changes. BUG=70427 TEST=None (plugins have not yet implemented Cocoa IME). Review URL: http://codereview.chromium.org/6259013 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@72190 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/renderer/webplugin_delegate_proxy.h')
-rw-r--r--chrome/renderer/webplugin_delegate_proxy.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chrome/renderer/webplugin_delegate_proxy.h b/chrome/renderer/webplugin_delegate_proxy.h
index 49bcc70..0d6eda0 100644
--- a/chrome/renderer/webplugin_delegate_proxy.h
+++ b/chrome/renderer/webplugin_delegate_proxy.h
@@ -90,8 +90,9 @@ class WebPluginDelegateProxy
virtual void SetContainerVisibility(bool is_visible);
// Informs the plugin that its enclosing window's frame has changed.
virtual void WindowFrameChanged(gfx::Rect window_frame, gfx::Rect view_frame);
- // Informs the plugin that text is avaiable from plugin IME.
- virtual void ImeCompositionConfirmed(const string16& text, int plugin_id);
+ // Informs the plugin that plugin IME has completed.
+ // If |text| is empty, composition was cancelled.
+ virtual void ImeCompositionCompleted(const string16& text, int plugin_id);
#endif
// IPC::Channel::Listener implementation:
@@ -164,7 +165,8 @@ class WebPluginDelegateProxy
void OnDeferResourceLoading(unsigned long resource_id, bool defer);
#if defined(OS_MACOSX)
- void OnSetImeEnabled(bool enabled);
+ void OnFocusChanged(bool focused);
+ void OnStartIme();
void OnBindFakePluginWindowHandle(bool opaque);
void OnUpdateGeometry_ACK(int ack_key);
void OnAcceleratedSurfaceSetIOSurface(gfx::PluginWindowHandle window,